@@ -71,8 +71,8 @@ itrax_radiograph <- function(file = "radiograph.tif",
             annotation_custom(rasterGrob(image,
                                          width  = unit(1, "npc"),
                                          height = unit(1, "npc")),
-                              ymax = max(as.numeric(rownames(image)))/-1,
-                              ymin = min(as.numeric(rownames(image)))/-1,
+                              ymax = max(as.numeric(rownames(image))),
+                              ymin = min(as.numeric(rownames(image))),
                               xmin = min(as.numeric(colnames(image))),
                               xmax = max(as.numeric(colnames(image))))
     )
